==> jc-1.4.0.tar.gz: javax/swing/border/TitledBorder__241BorderPainter.h <==
// class javax.swing.border.TitledBorder$1BorderPainter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bfaeb4b9de7c02c0 javax_swing_border_TitledBorder__241BorderPainter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_border_TitledBorder__241BorderPainter_H_
#define _JC_javax_swing_border_TitledBorder__241BorderPainter_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;
struct _jc_javax_swing_border_TitledBorder$object;

// Typedefs
typedef struct _jc_javax_swing_border_TitledBorder__241BorderPainter$sub_refs	_jc_javax_swing_border_TitledBorder__241BorderPainter$sub_refs;
typedef struct _jc_javax_swing_border_TitledBorder__241BorderPainter$sub_nonrefs	_jc_javax_swing_border_TitledBorder__241BorderPainter$sub_nonrefs;
typedef struct _jc_javax_swing_border_TitledBorder__241BorderPainter$refs	_jc_javax_swing_border_TitledBorder__241BorderPainter$refs;
typedef struct _jc_javax_swing_border_TitledBorder__241BorderPainter$nonrefs	_jc_javax_swing_border_TitledBorder__241BorderPainter$nonrefs;
typedef struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object	_jc_javax_swing_border_TitledBorder__241BorderPainter$object;

typedef const struct _jc_javax_swing_border_TitledBorder__241BorderPainter$vmethods	_jc_javax_swing_border_TitledBorder__241BorderPainter$vmethods;
typedef const struct _jc_javax_swing_border_TitledBorder__241BorderPainter$vtable	_jc_javax_swing_border_TitledBorder__241BorderPainter$vtable;
typedef const struct _jc_javax_swing_border_TitledBorder__241BorderPainter$vtype	_jc_javax_swing_border_TitledBorder__241BorderPainter$vtype;

// Constructors
extern void _jc_javax_swing_border_TitledBorder__241BorderPainter$method$_init$42750be2adc16b46(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_javax_swing_border_TitledBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_object *, jint, jint, jint, jint);

// Virtual methods
extern void _jc_javax_swing_border_TitledBorder__241BorderPainter$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_java_awt_Graphics$object *);
extern void _jc_javax_swing_border_TitledBorder__241BorderPainter$method$paint$e319477eb8d59dca(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
extern void _jc_javax_swing_border_TitledBorder__241BorderPainter$method$paintExcept$813c1fa9367e2850(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_border_TitledBorder__241BorderPainter$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_border_TitledBorder__241BorderPainter$method_info$paint$e319477eb8d59dca;
extern _jc_method _jc_javax_swing_border_TitledBorder__241BorderPainter$method_info$paintExcept$813c1fa9367e2850;

// Virtual methods structure
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$vmethods {
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_java_awt_Graphics$object *);
	void	(*paint$e319477eb8d59dca)(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
	void	(*paintExcept$813c1fa9367e2850)(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_TitledBorder__241BorderPainter$vmethods	javax_swing_border_TitledBorder__241BorderPainter;
};

// Vtype
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$vtype {
	_jc_type			type;
	_jc_javax_swing_border_TitledBorder__241BorderPainter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$sub_refs {
	struct _jc_java_awt_Component$object	*c;
	struct _jc_object	*b;
	struct _jc_javax_swing_border_TitledBorder$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$refs {
    _jc_javax_swing_border_TitledBorder__241BorderPainter$sub_refs	javax_swing_border_TitledBorder__241BorderPainter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$sub_nonrefs {
	jint	x;
	jint	y;
	jint	width;
	jint	height;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_TitledBorder__241BorderPainter$sub_nonrefs	javax_swing_border_TitledBorder__241BorderPainter;
};

// Object instance structure
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object {
	_jc_javax_swing_border_TitledBorder__241BorderPainter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_border_TitledBorder__241BorderPainter$vtype	*vtype;
	_jc_javax_swing_border_TitledBorder__241BorderPainter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_border_TitledBorder__241BorderPainter$vtype _jc_javax_swing_border_TitledBorder__241BorderPainter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_border_TitledBorder__241BorderPainter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_border_TitledBorder__241BorderPainter$class_object;

#endif	/* _JC_javax_swing_border_TitledBorder__241BorderPainter_H_ */

==> jc-1.4.6.tar.gz: javax/swing/border/TitledBorder__241BorderPainter.h <==
// class javax.swing.border.TitledBorder$1BorderPainter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bfaeb4b9de7c02c0 javax_swing_border_TitledBorder__241BorderPainter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_border_TitledBorder__241BorderPainter_H_
#define _JC_javax_swing_border_TitledBorder__241BorderPainter_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;
struct _jc_javax_swing_border_TitledBorder$object;

// Typedefs
typedef struct _jc_javax_swing_border_TitledBorder__241BorderPainter$sub_refs	_jc_javax_swing_border_TitledBorder__241BorderPainter$sub_refs;
typedef struct _jc_javax_swing_border_TitledBorder__241BorderPainter$sub_nonrefs	_jc_javax_swing_border_TitledBorder__241BorderPainter$sub_nonrefs;
typedef struct _jc_javax_swing_border_TitledBorder__241BorderPainter$refs	_jc_javax_swing_border_TitledBorder__241BorderPainter$refs;
typedef struct _jc_javax_swing_border_TitledBorder__241BorderPainter$nonrefs	_jc_javax_swing_border_TitledBorder__241BorderPainter$nonrefs;
typedef struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object	_jc_javax_swing_border_TitledBorder__241BorderPainter$object;

typedef const struct _jc_javax_swing_border_TitledBorder__241BorderPainter$vmethods	_jc_javax_swing_border_TitledBorder__241BorderPainter$vmethods;
typedef const struct _jc_javax_swing_border_TitledBorder__241BorderPainter$vtable	_jc_javax_swing_border_TitledBorder__241BorderPainter$vtable;
typedef const struct _jc_javax_swing_border_TitledBorder__241BorderPainter$vtype	_jc_javax_swing_border_TitledBorder__241BorderPainter$vtype;

// Constructors
extern void _jc_javax_swing_border_TitledBorder__241BorderPainter$method$_init$42750be2adc16b46(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_javax_swing_border_TitledBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_border_TitledBorder__241BorderPainter$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_border_TitledBorder__241BorderPainter$method$paint$e319477eb8d59dca(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_border_TitledBorder__241BorderPainter$method$paintExcept$813c1fa9367e2850(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_border_TitledBorder__241BorderPainter$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_border_TitledBorder__241BorderPainter$method_info$paint$e319477eb8d59dca;
extern _jc_method _jc_javax_swing_border_TitledBorder__241BorderPainter$method_info$paintExcept$813c1fa9367e2850;

// Virtual methods structure
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$vmethods {
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
	void	(*paint$e319477eb8d59dca)(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
	void	(*paintExcept$813c1fa9367e2850)(_jc_env *, struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_TitledBorder__241BorderPainter$vmethods	javax_swing_border_TitledBorder__241BorderPainter;
};

// Vtype
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$vtype {
	_jc_type			type;
	_jc_javax_swing_border_TitledBorder__241BorderPainter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$sub_refs {
	struct _jc_java_awt_Component$object	*c;
	struct _jc_object	*b;
	struct _jc_javax_swing_border_TitledBorder$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$refs {
    _jc_javax_swing_border_TitledBorder__241BorderPainter$sub_refs	javax_swing_border_TitledBorder__241BorderPainter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$sub_nonrefs {
	jint	x;
	jint	y;
	jint	width;
	jint	height;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_TitledBorder__241BorderPainter$sub_nonrefs	javax_swing_border_TitledBorder__241BorderPainter;
};

// Object instance structure
struct _jc_javax_swing_border_TitledBorder__241BorderPainter$object {
	_jc_javax_swing_border_TitledBorder__241BorderPainter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_border_TitledBorder__241BorderPainter$vtype	*vtype;
	_jc_javax_swing_border_TitledBorder__241BorderPainter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_border_TitledBorder__241BorderPainter$vtype _jc_javax_swing_border_TitledBorder__241BorderPainter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_border_TitledBorder__241BorderPainter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_border_TitledBorder__241BorderPainter$class_object;

#endif	/* _JC_javax_swing_border_TitledBorder__241BorderPainter_H_ */
